"""Esse método contém funções utilitárias
para construção e obtenção de extratores
de características através de nomes.
"""

from __future__ import annotations

from aibox.nlp.core import FeatureExtractor
from aibox.nlp.features.utils.aggregator import AggregatedFeatureExtractor

from .class_registry import get_class


def get_extractor(
    features: str | list[str], configs: list[dict] = None
) -> FeatureExtractor:
    """Obtém um extrator de características para
    todas as características na lista `features`.

    Args:
        features (str, list[str]): lista com o nome dos extratores
            de características.
        configs (list[dict], opcional): parâmetros para serem passados
            aos construtores dos extratores de características.

    Returns:
        Extrator de características.
    """
    if not isinstance(features, list):
        features = [features]

    if configs is None:
        configs = [dict() for _ in features]

    features = list(features)
    configs = list(configs)
    assert len(configs) == len(features)

    extractors = []
    for feature, config in zip(features, configs):
        extractor = get_class(features[0])
        assert issubclass(
            extractor, FeatureExtractor
        ), "Esse nome não corresponde a um extrator de características."
        extractors.append(extractor(**configs[0]))

    return (
        AggregatedFeatureExtractor(*extractors)
        if len(extractors) > 1
        else extractors[0]
    )
